@@ -24,7 +24,7 @@
 /* FIXME: Should use BonoboUIHandler.  */
 
 #include <config.h>
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n.h>
 #include <gnome.h>
 #include <bonobo.h>
 
@@ -237,7 +237,7 @@ toolbar_apply_color (GtkHTMLControlData *cd)
 	GdkColor *color;
 	gboolean default_color;
 
-	color = color_combo_get_color (COLOR_COMBO (cd->combo), &default_color);
+	color = gi_color_combo_get_color (GI_COLOR_COMBO (cd->combo), &default_color);
 	apply_color (color, cd);
 	if (color)
 		gdk_color_free (color);
@@ -262,16 +262,17 @@ unset_focus (GtkWidget *w, gpointer data)
 }
 
 static void
-set_color_combo (GtkHTML *html, GtkHTMLControlData *cd)
+set_gi_color_combo (GtkHTML *html, GtkHTMLControlData *cd)
 {
-	color_combo_set_color (COLOR_COMBO (cd->combo),
-			       &html_colorset_get_color_allocated (html->engine->painter, HTMLTextColor)->color);
+	gi_color_combo_set_color (GI_COLOR_COMBO (cd->combo),
+			       &html_colorset_get_color_allocated (html->engine->settings->color_set,
+								   html->engine->painter, HTMLTextColor)->color);
 }
 
 static void
 realize_engine (GtkHTML *html, GtkHTMLControlData *cd)
 {
-	set_color_combo (html, cd);
+	set_gi_color_combo (html, cd);
 	g_signal_handlers_disconnect_matched (html, G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA,
 					      0, 0, NULL, G_CALLBACK (realize_engine), cd);
 }
@@ -280,13 +281,13 @@ static void
 load_done (GtkHTML *html, GtkHTMLControlData *cd)
 {
 	if (GTK_WIDGET_REALIZED (cd->html))
-		set_color_combo (html, cd);
+		set_gi_color_combo (html, cd);
 	else
 		g_signal_connect (cd->html, "realize", G_CALLBACK (realize_engine), cd);
 }
 
 static GtkWidget *
-setup_color_combo (GtkHTMLControlData *cd)
+setup_gi_color_combo (GtkHTMLControlData *cd)
 {
 	HTMLColor *color;
 
@@ -297,7 +298,7 @@ setup_color_combo (GtkHTMLControlData *cd)
 		g_signal_connect (cd->html, "realize", G_CALLBACK (realize_engine), cd);
         g_signal_connect (cd->html, "load_done", G_CALLBACK (load_done), cd);
 
-	cd->combo = color_combo_new (NULL, _("Automatic"), &color->color, color_group_fetch ("toolbar_text", cd));
+	cd->combo = gi_color_combo_new (NULL, _("Automatic"), &color->color, color_group_fetch ("toolbar_text", cd));
         g_signal_connect (cd->combo, "color_changed", G_CALLBACK (color_changed), cd);
 
 	gtk_widget_show_all (cd->combo);
@@ -503,28 +504,46 @@ editor_toolbar_unindent_cb (GtkWidget *widget,
 
 /* Editor toolbar.  */
 
+enum EditorAlignmentButtons {
+	EDITOR_ALIGNMENT_LEFT,
+	EDITOR_ALIGNMENT_CENTER,
+	EDITOR_ALIGNMENT_RIGHT
+};
 static GnomeUIInfo editor_toolbar_alignment_group[] = {
-	GNOMEUIINFO_ITEM_STOCK (N_("Left align"), N_("Left justifies the paragraphs"),
-				editor_toolbar_left_align_cb, GTK_STOCK_JUSTIFY_LEFT),
-	GNOMEUIINFO_ITEM_STOCK (N_("Center"), N_("Center justifies the paragraphs"),
-				editor_toolbar_center_cb, GTK_STOCK_JUSTIFY_CENTER),
-	GNOMEUIINFO_ITEM_STOCK (N_("Right align"), N_("Right justifies the paragraphs"),
-				editor_toolbar_right_align_cb, GTK_STOCK_JUSTIFY_RIGHT),
+	{ GNOME_APP_UI_ITEM, N_("Left align"), N_("Left justifies the paragraphs"),
+	  editor_toolbar_left_align_cb, NULL, NULL, GNOME_APP_PIXMAP_FILENAME },
+	{ GNOME_APP_UI_ITEM, N_("Center"), N_("Center justifies the paragraphs"),
+	  editor_toolbar_center_cb, NULL, NULL, GNOME_APP_PIXMAP_FILENAME },
+	{ GNOME_APP_UI_ITEM, N_("Right align"), N_("Right justifies the paragraphs"),
+	  editor_toolbar_right_align_cb, NULL, NULL, GNOME_APP_PIXMAP_FILENAME },
 	GNOMEUIINFO_END
 };
 
+enum EditorToolbarButtons {
+	EDITOR_TOOLBAR_TT,
+	EDITOR_TOOLBAR_BOLD,
+	EDITOR_TOOLBAR_ITALIC,
+	EDITOR_TOOLBAR_UNDERLINE,
+	EDITOR_TOOLBAR_STRIKEOUT,
+	EDITOR_TOOLBAR_SEP1,
+	EDITOR_TOOLBAR_ALIGNMENT,
+	EDITOR_TOOLBAR_SEP2,
+	EDITOR_TOOLBAR_UNINDENT,
+	EDITOR_TOOLBAR_INDENT
+};
+
 static GnomeUIInfo editor_toolbar_style_uiinfo[] = {
 
 	{ GNOME_APP_UI_TOGGLEITEM, N_("Typewriter"), N_("Toggle typewriter font style"),
-	  editor_toolbar_tt_cb, NULL, NULL, GNOME_APP_PIXMAP_FILENAME, GTKHTML_DATADIR "/icons/font-tt-24.png" },
+	  editor_toolbar_tt_cb, NULL, NULL, GNOME_APP_PIXMAP_FILENAME },
 	{ GNOME_APP_UI_TOGGLEITEM, N_("Bold"), N_("Makes the text bold"),
-	  editor_toolbar_bold_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK, GTK_STOCK_BOLD },
+	  editor_toolbar_bold_cb, NULL, NULL, GNOME_APP_PIXMAP_FILENAME },
 	{ GNOME_APP_UI_TOGGLEITEM, N_("Italic"), N_("Makes the text italic"),
-	  editor_toolbar_italic_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK, GTK_STOCK_ITALIC },
+	  editor_toolbar_italic_cb, NULL, NULL, GNOME_APP_PIXMAP_FILENAME },
 	{ GNOME_APP_UI_TOGGLEITEM, N_("Underline"), N_("Underlines the text"),
-	  editor_toolbar_underline_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK, GTK_STOCK_UNDERLINE },
+	  editor_toolbar_underline_cb, NULL, NULL, GNOME_APP_PIXMAP_FILENAME },
 	{ GNOME_APP_UI_TOGGLEITEM, N_("Strikeout"), N_("Strikes out the text"),
-	  editor_toolbar_strikeout_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK, GTK_STOCK_STRIKETHROUGH },
+	  editor_toolbar_strikeout_cb, NULL, NULL, GNOME_APP_PIXMAP_FILENAME },
 
 	GNOMEUIINFO_SEPARATOR,
 
@@ -532,10 +551,10 @@ static GnomeUIInfo editor_toolbar_style_uiinfo[] = {
 
 	GNOMEUIINFO_SEPARATOR,
 
-	GNOMEUIINFO_ITEM_STOCK (N_("Unindent"), N_("Indents the paragraphs less"),
-				editor_toolbar_unindent_cb, GNOME_STOCK_TEXT_UNINDENT),
-	GNOMEUIINFO_ITEM_STOCK (N_("Indent"), N_("Indents the paragraphs more"),
-				editor_toolbar_indent_cb, GNOME_STOCK_TEXT_INDENT),
+	{ GNOME_APP_UI_ITEM, N_("Unindent"), N_("Indents the paragraphs less"),
+	  editor_toolbar_unindent_cb, NULL, NULL, GNOME_APP_PIXMAP_FILENAME },
+	{ GNOME_APP_UI_ITEM, N_("Indent"), N_("Indents the paragraphs more"),
+	  editor_toolbar_indent_cb, NULL, NULL, GNOME_APP_PIXMAP_FILENAME },
 
 	GNOMEUIINFO_END
 };
@@ -591,6 +610,21 @@ create_style_toolbar (GtkHTMLControlData *cd)
 	domain = g_strdup (textdomain (NULL));
 	textdomain (GETTEXT_PACKAGE);
 	
+	editor_toolbar_style_uiinfo [EDITOR_TOOLBAR_TT].pixmap_info = GTKHTML_DATADIR "/icons/font-tt-24.png";
+	editor_toolbar_style_uiinfo [EDITOR_TOOLBAR_BOLD].pixmap_info = gnome_icon_theme_lookup_icon (cd->icon_theme, "stock_text_bold", 24, NULL, NULL);
+	editor_toolbar_style_uiinfo [EDITOR_TOOLBAR_ITALIC].pixmap_info = gnome_icon_theme_lookup_icon (cd->icon_theme, "stock_text_italic", 24, NULL, NULL);
+	editor_toolbar_style_uiinfo [EDITOR_TOOLBAR_UNDERLINE].pixmap_info = gnome_icon_theme_lookup_icon (cd->icon_theme, "stock_text_underlined", 24, NULL, NULL);
+	editor_toolbar_style_uiinfo [EDITOR_TOOLBAR_STRIKEOUT].pixmap_info = gnome_icon_theme_lookup_icon (cd->icon_theme, "stock_text-strikethrough", 24, NULL, NULL);
+	editor_toolbar_style_uiinfo [EDITOR_TOOLBAR_UNINDENT].pixmap_info = gnome_icon_theme_lookup_icon (cd->icon_theme, "stock_text_unindent", 24, NULL, NULL);
+	editor_toolbar_style_uiinfo [EDITOR_TOOLBAR_INDENT].pixmap_info = gnome_icon_theme_lookup_icon (cd->icon_theme, "stock_text_indent", 24, NULL, NULL);
+
+	((GnomeUIInfo *) editor_toolbar_style_uiinfo [EDITOR_TOOLBAR_ALIGNMENT].moreinfo) [EDITOR_ALIGNMENT_LEFT].pixmap_info
+		= gnome_icon_theme_lookup_icon (cd->icon_theme, "stock_text_left", 24, NULL, NULL);
+	((GnomeUIInfo *) editor_toolbar_style_uiinfo [EDITOR_TOOLBAR_ALIGNMENT].moreinfo) [EDITOR_ALIGNMENT_CENTER].pixmap_info
+		= gnome_icon_theme_lookup_icon (cd->icon_theme, "stock_text_center", 24, NULL, NULL);
+	((GnomeUIInfo *) editor_toolbar_style_uiinfo [EDITOR_TOOLBAR_ALIGNMENT].moreinfo) [EDITOR_ALIGNMENT_RIGHT].pixmap_info
+		= gnome_icon_theme_lookup_icon (cd->icon_theme, "stock_text_right", 24, NULL, NULL);
+
 	gnome_app_fill_toolbar_with_data (GTK_TOOLBAR (cd->toolbar_style), editor_toolbar_style_uiinfo, NULL, cd);
 
 	/* restore the stolen domain */
@@ -598,7 +632,7 @@ create_style_toolbar (GtkHTMLControlData *cd)
 	g_free (domain);
 
 	gtk_toolbar_append_widget (GTK_TOOLBAR (cd->toolbar_style),
-				   setup_color_combo (cd),
+				   setup_gi_color_combo (cd),
 				   NULL, NULL);
 
 	cd->font_style_changed_connection_id
@@ -606,11 +640,11 @@ create_style_toolbar (GtkHTMLControlData *cd)
 				      G_CALLBACK (insertion_font_style_changed_cb), cd);
 
 	/* The following SUCKS!  */
-	cd->tt_button        = editor_toolbar_style_uiinfo [0].widget;
-	cd->bold_button      = editor_toolbar_style_uiinfo [1].widget;
-	cd->italic_button    = editor_toolbar_style_uiinfo [2].widget;
-	cd->underline_button = editor_toolbar_style_uiinfo [3].widget;
-	cd->strikeout_button = editor_toolbar_style_uiinfo [4].widget;
+	cd->tt_button        = editor_toolbar_style_uiinfo [EDITOR_TOOLBAR_TT].widget;
+	cd->bold_button      = editor_toolbar_style_uiinfo [EDITOR_TOOLBAR_BOLD].widget;
+	cd->italic_button    = editor_toolbar_style_uiinfo [EDITOR_TOOLBAR_ITALIC].widget;
+	cd->underline_button = editor_toolbar_style_uiinfo [EDITOR_TOOLBAR_UNDERLINE].widget;
+	cd->strikeout_button = editor_toolbar_style_uiinfo [EDITOR_TOOLBAR_STRIKEOUT].widget;
 
 	cd->left_align_button = editor_toolbar_alignment_group[0].widget;
 	cd->center_button = editor_toolbar_alignment_group[1].widget;
